#! /bin/ksh
# @(#)start_geneclust_ui 1.0.0b11
#
# Script wrapper for executing the JAVA front end of GeneClust
#

typeset script_name_without_path="${0##*/}"
typeset -r script_name="${script_name_without_path%.*}"
typeset -r path_gchome=${GCHOME:=`pwd`}
typeset path_gcdata=$GCDATA
typeset path_gcoutput=$GCOUTPUT
typeset path_shome=$SHOME
typeset exec_splus
typeset -r app_class_name=GeneClust
typeset -r policy_file=$app_class_name.policy
typeset -r jar_file=$app_class_name.jar


if [ ${#SHOME} -eq 0 ] ;
then
    print -u2 "Environment variable 'SHOME' must be set to run this"
    print -u2 "application. It must point to the S-plus root directory."
    exit 2
else
    if [ ! -d $SHOME ] ;
    then
        print -u2 "Directory specified by environment variable 'SHOME'"
        print -u2 "<" $SHOME "> does not exist."
        exit 2
    fi
fi

if [ ${#GCHOME} -eq 0 ] ;
then
    print -u2 "Environment variable 'GCHOME' must be set to run this"
    print -u2 "application. It must point to the installation root directory."
    exit 2
else
    if [ ! -d $GCHOME ] ;
    then
        print -u2 "Directory specified by environment variable 'GCHOME'"
        print -u2 "<" $GCHOME "> does not exist."
        exit 2
    fi
fi

if [ ${#GCDATA} -eq 0 ] ;
then
    path_gcdata=$path_gchome/data
else
    if [ ! -d $GCDATA ] ;
    then
        print -u2 "Directory specified by environment variable 'GCDATA'"
        print -u2 "<" $GCDATA "> does not exist."
        exit 2
    fi
fi

if [ ${#GCOUTPUT} -eq 0 ] ;
then
    path_gcoutput=$path_gchome/output
else
    if [ ! -d $GCOUTPUT ] ;
    then
        print -u2 "Directory specified by environment variable 'GCOUTPUT'"
        print -u2 "<" $GCOUTPUT "> does not exist."
        exit 2
    fi
fi

# Determine what S-plus command interpreter is named, if possible
exec_splus=$( $path_gchome/bin/get_splus_exec )
if [ ${#exec_splus} -eq 0 ] ;
then
    exit 2
fi

#
# Start JAVA front end
#
cd $path_gchome
java \
    -Dgeneclust.home=$path_gchome \
    -Dgeneclust.data=$path_gcdata \
    -Dgeneclust.output=$path_gcoutput \
    -Dsplus.shome=$path_shome \
    -Dsplus.exec=$exec_splus \
    -Djava.security.policy=java/policy/$policy_file \
    -Xfuture \
    -jar java/jars/$jar_file $1

exit $?

